@@ -24,16 +24,19 @@
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
 
 G_BEGIN_DECLS
 
 gboolean	 gpk_dialog_embed_package_list_widget	(GtkDialog	*dialog,
-							 PkPackageList	*list);
+							 GPtrArray	*array);
 gboolean	 gpk_dialog_embed_file_list_widget	(GtkDialog	*dialog,
 							 GPtrArray	*files);
 gboolean	 gpk_dialog_embed_do_not_show_widget	(GtkDialog	*dialog,
 							 const gchar	*key);
+gboolean	 gpk_dialog_embed_download_size_widget	(GtkDialog	*dialog,
+							 const gchar	*title,
+							 guint64	 size);
 gchar		*gpk_dialog_package_id_name_join_locale	(gchar		**package_ids);
 
 G_END_DECLS
